@@ -563,10 +563,10 @@ class DataTransform(forms.ModelForm):
                                                                      extra=self.instance.get_children().count() + 1
                                                                      )
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
-                    instance=self.instance,
+                    queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': str(self.instance.id)}]
+                    initial=[{'parent': self.instance,}]
                 )
                 self.nested_constants_form = DataConstantsTransformerInlineFormset(
                     instance=self.instance,
@@ -592,18 +592,18 @@ class DataTransform(forms.ModelForm):
 
 
     def as_p(self):
-        # super(self.__class__,self).as_p()
-        forms = ''
-        forms = '   '.join([forms,super(self.__class__,self).as_p()])
+        print('wtf')
+        print('instance: ' + str(self.instance.id))
+        forms = super(self.__class__,self).as_p()
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            forms = ' '.join([forms,self.nested_constants_form.as_p()])
+            forms = '\n '.join([forms,self.nested_constants_form.as_p()])
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            forms = ' '.join([forms,self.nested_hardware_outputs_form.as_p()])
+            forms = '\n '.join([forms,self.nested_hardware_outputs_form.as_p()])
         if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            forms = ' '.join([forms,self.nested_hardware_stats_form.as_p()])
+            forms = '\n '.join([forms,self.nested_hardware_stats_form.as_p()])
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            forms = '       -'.join([forms,self.nested_data_transformer_form.as_p()])
+            forms = '\n       -'.join([forms,self.nested_data_transformer_form.as_p()])
         return mark_safe(forms)
 
     class Meta:
@@ -633,10 +633,10 @@ class DataTransformRoot(forms.ModelForm):
                                                              extra=self.instance.get_children().count() + 1
                                                              )
         self.nested_data_transformer_form = dataTransformerInlineFormset(
-            instance=self.instance,
+            queryset=self.instance.get_children(),
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            initial=[{'parent': str(self.instance.id),}]
+            initial=[{'parent': self.instance,}]
         )
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
@@ -658,18 +658,16 @@ class DataTransformRoot(forms.ModelForm):
         )
 
     def as_p(self):
-        # super(self.__class__,self).as_p()
-        forms = ''
-        forms = '   '.join([forms,super(self.__class__,self).as_p()])
+        forms = super(self.__class__,self).as_p()
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            forms = ' '.join([forms,self.nested_constants_form.as_p()])
+            forms = '\n'.join([forms,self.nested_constants_form.as_p()])
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            forms = ' '.join([forms,self.nested_hardware_outputs_form.as_p()])
+            forms = '\n'.join([forms,self.nested_hardware_outputs_form.as_p()])
         if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            forms = ' '.join([forms,self.nested_hardware_stats_form.as_p()])
+            forms = '\n'.join([forms,self.nested_hardware_stats_form.as_p()])
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            forms = '       -'.join([forms,self.nested_data_transformer_form.as_p()])
+            forms = '\n       -'.join([forms,self.nested_data_transformer_form.as_p()])
         return mark_safe(forms)
 
     class Meta:
